@@ -1,7 +1,7 @@
 package Finance::Bank::ID::Mandiri;
 
-our $DATE = '2017-07-03'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $DATE = '2017-07-14'; # DATE
+our $VERSION = '0.36'; # VERSION
 
 use 5.010001;
 
@@ -193,15 +193,15 @@ sub get_statement {
     if (!$start_date) {
         if (defined $args{days}) {
             $start_date = $end_date->clone->subtract(days=>($args{days}-1));
-            $self->logger->debugf(
+            $self->logger->debug(sprintf(
                 'Setting start_date to %04d-%02d-%02d (end_date - %d days)',
                 $start_date->year, $start_date->month, $start_date->day,
-                $args{days});
+                $args{days}));
         } else {
             $start_date = $end_date->clone->subtract(months=>1);
-            $self->logger->debugf(
+            $self->logger->debug(sprintf(
                 'Setting start_date to %04d-%02d-%02d (end_date - 1mo)',
-                $start_date->year, $start_date->month, $start_date->day);
+                $start_date->year, $start_date->month, $start_date->day));
         }
     }
 
@@ -638,7 +638,7 @@ Finance::Bank::ID::Mandiri - Check your Bank Mandiri accounts from Perl
 
 =head1 VERSION
 
-This document describes version 0.35 of Finance::Bank::ID::Mandiri (from Perl distribution Finance-Bank-ID-Mandiri), released on 2017-07-03.
+This document describes version 0.36 of Finance::Bank::ID::Mandiri (from Perl distribution Finance-Bank-ID-Mandiri), released on 2017-07-14.
 
 =head1 SYNOPSIS
 
